﻿using System;
using System.Windows.Forms;
using System.Runtime.InteropServices;

namespace DotNetControls
{
    [Guid("00FE5130-0E77-4693-930D-1FE194569A01")]
    [InterfaceType(ComInterfaceType.InterfaceIsIDispatch)]
    public interface MenubarEvents
    {
        [DispId(1)]
        void ItemClick(string ItemName);
    }

    [Guid("F38ABF27-314A-4027-BE29-DF345B9E613E")]
    [ClassInterface(ClassInterfaceType.None)]
    [ComSourceInterfaces(typeof(MenubarEvents))]
    public partial class Menubar : COMUserControl, MenubarInterface
    {
        public Menubar()
        {
            InitializeComponent();
        }

        public delegate void ItemClickEventHandler(string itemName);
        event ItemClickEventHandler ItemClick;
        private void MenuItem_Click(object sender, EventArgs e)
        {
            if (ItemClick != null)
            {
                ToolStripMenuItem item = (ToolStripMenuItem)sender;
                ItemClick(item.Name);
            }
        }

        public ToolStripMenuItem AddPad(string name, string text, string shortcutKey)
        {
            ToolStripMenuItem newItem = new ToolStripMenuItem();
            this.menuStrip.Items.Add(newItem);
            newItem.Name = name;
            newItem.AutoSize = true;
            newItem.Text = text;
            if (shortcutKey != "")
            {
                char key = shortcutKey.ToUpper().ToCharArray()[0];
                newItem.ShortcutKeys = ((Keys)((Keys.Alt | (Keys)(byte)key)));
            }
            return newItem;
        }

        public ToolStripMenuItem AddBar(ToolStripMenuItem menuPad, string name, string text, string shortcutKey, string imageFile)
        {
            ToolStripMenuItem newBar = new ToolStripMenuItem();
            menuPad.DropDownItems.Add(newBar);
            newBar.Name = name;
            newBar.AutoSize = true;
            newBar.Text = text;
            newBar.Click += new System.EventHandler(this.MenuItem_Click);
            if (imageFile != "")
            {
                newBar.Image = System.Drawing.Image.FromFile(imageFile);
                newBar.ImageTransparentColor = System.Drawing.Color.White;
            }
            if (shortcutKey != "")
            {
                char key = shortcutKey.ToUpper().ToCharArray()[0];
                newBar.ShortcutKeys = ((Keys)((Keys.Control | (Keys)(byte)key)));
            }
            return newBar;
        }

        public void AddSeparator(ToolStripMenuItem menuPad)
        {
            ToolStripSeparator newBar = new ToolStripSeparator();
            menuPad.DropDownItems.Add(newBar);
            newBar.Size = new System.Drawing.Size(149, 6);
        }
    }

    public interface MenubarInterface
    {
        ToolStripMenuItem AddPad(string name, string text, string shortcutKey);
        ToolStripMenuItem AddBar(ToolStripMenuItem menuPad, string name, string text, string shortcutKey, string imageFile);
        void AddSeparator(ToolStripMenuItem menuPad);
    }
}
