﻿using System;
using System.Windows.Forms;
using System.Runtime.InteropServices;

namespace DotNetControls
{
    [Guid("4CEA9FE7-3528-4F50-BC29-0610CA0EBF31")]
    [InterfaceType(ComInterfaceType.InterfaceIsIDispatch)]
    public interface TreeViewEvents
    {
        [DispId(1)]
        void NodeClick(string NodeKey);
    }

    [Guid("653E6376-3E1B-4E77-92AE-1E0FE982C662")]
    [ClassInterface(ClassInterfaceType.None)]
    [ComSourceInterfaces(typeof(TreeViewEvents))]
    public partial class TreeView : COMUserControl, TreeViewInterface
    {
        public TreeView()
        {
            InitializeComponent();
            this.Control.NodeMouseClick += new TreeNodeMouseClickEventHandler(Node_Click);
        }

        public delegate void NodeClickEventHandler(string itemName);
        event NodeClickEventHandler NodeClick;
        private void Node_Click(object sender, TreeNodeMouseClickEventArgs e)
        {
            if (NodeClick != null)
            {
                NodeClick(e.Node.Name);
            }
        }

        public void LoadImage(string key, string imageFile)
        {
            this.imageList.Images.Add(key, System.Drawing.Image.FromFile(imageFile));
        }

        public TreeNode AddNode(string key, string text, string imageKey)
        {
            TreeNode node = this.Control.Nodes.Add(key, text, imageKey);
            node.SelectedImageKey = imageKey;
            return node;
        }

        public TreeNode AddChildNode(string parentKey, string key, string text, string imageKey)
        {
            TreeNode[] nodes = this.Control.Nodes.Find(parentKey, true);
            TreeNode parentNode = nodes[0];
            TreeNode node = parentNode.Nodes.Add(key, text, imageKey);
            node.SelectedImageKey = imageKey;
            return node;
        }
    }

    public interface TreeViewInterface
    {
        void LoadImage(string key, string imageFile);
        TreeNode AddNode(string key, string text, string imageKey);
        TreeNode AddChildNode(string parentKey, string key, string text, string imageKey);
    }
}
